package VMOMI::HostCapabilityFtUnsupportedReason;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
